=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2006-01-07 23:51:00 +0000
+++ bzrlib/tests/test_transform.py	2006-01-08 21:23:51 +0000
@@ -3,6 +3,7 @@
 from bzrlib.transform import TreeTransform
 from bzrlib.errors import DuplicateKey, MalformedTransform, NoSuchFile
 from bzrlib.osutils import file_kind
+import os
 
 class TestTreeTransform(TestCaseInTempDir):
     def test_build(self):
@@ -32,10 +33,15 @@
             oz_id = transform.create_path('oz', root)
             transform.create_directory(oz_id)
             transform.version_file('ozzie', oz_id)
+            wiz_id = transform.create_path('wizard', oz_id)
+            transform.create_symlink('behind_curtain', wiz_id)
+            transform.version_file('wiz-id', wiz_id)
             transform.apply()
             self.assertEqual('contents', file('name').read())
             self.assertEqual(wt.path2id('name'), 'my_pretties')
             self.assertEqual('directory', file_kind('oz'))
+            self.assertEqual(file_kind('oz/wizard'), 'symlink')
+            self.assertEqual(os.readlink('oz/wizard'), 'behind_curtain')
         finally:
             transform.finalize()
         # is it safe to finalize repeatedly?
@@ -53,6 +59,8 @@
             dorothy = transform.new_directory('dorothy', oz, 'dorothy-id')
             toto = transform.new_file('toto', dorothy, 'toto-contents', 
                                       'toto-id')
+            wizard = transform.new_symlink('wizard', oz, 'wizard-target', 
+                                           'wizard-id')
             transform.apply()
             self.assertEqual(len(transform.find_conflicts()), 0)
             self.assertEqual('contents', file('name').read())
@@ -60,7 +68,9 @@
             self.assertEqual(wt.path2id('oz'), 'oz-id')
             self.assertEqual(wt.path2id('oz/dorothy'), 'dorothy-id')
             self.assertEqual(wt.path2id('oz/dorothy/toto'), 'toto-id')
+            self.assertEqual(wt.path2id('oz/wizard'), 'wizard-id')
             self.assertEqual('toto-contents', file('oz/dorothy/toto').read())
+            self.assertEqual(os.readlink('oz/wizard'), 'wizard-target')
         finally:
             transform.finalize()
 

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2006-01-08 20:43:09 +0000
+++ bzrlib/transform.py	2006-01-08 21:23:51 +0000
@@ -98,6 +98,14 @@
         """
         unique_add(self._new_contents, trans_id, ('directory',))
 
+    def create_symlink(self, target, trans_id):
+        """Schedule creation of a new symbolic link.
+
+        target is a bytestring.
+        See also new_symlink.
+        """
+        unique_add(self._new_contents, trans_id, ('symlink', target))
+
     def version_file(self, file_id, trans_id):
         """Schedule a file to become versioned."""
         unique_add(self._new_id, trans_id, file_id)
@@ -277,6 +285,9 @@
                 f.close()
             elif kind == 'directory':
                 os.mkdir(self._tree.abspath(path))
+            elif kind == 'symlink':
+                target = self._new_contents[trans_id][1]
+                os.symlink(target, path)
 
             if trans_id in self._new_id:
                 if kind is None:
@@ -318,6 +329,19 @@
         self.create_directory(trans_id)
         return trans_id 
 
+    def new_symlink(self, name, parent_id, target, file_id=None):
+        """\
+        Convenience method to create symbolic link.
+        
+        name is the name of the symlink to create.
+        parent_id is the transaction id of the parent directory of the symlink.
+        target is a bytestring of the target of the symlink.
+        file_id is the inventory ID of the file, if it is to be versioned.
+        """
+        trans_id = self.new_entry(name, parent_id, file_id)
+        self.create_symlink(target, trans_id)
+        return trans_id
+
 
 class FinalPaths(object):
     """\

